@@ -33,7 +33,7 @@ sub handler {
 					handler => new KUB::Manage(cfg => $rsc),
 				),
 				fallback => new Xyzzy::CAS(cfg => $rsc,
-					cas_snoop => 1, snoop => 1,
+					snoop => 1,
 					handler => new KUB::Redirect(cfg => $rsc,
 						fallback => new KUB::Notfound(cfg => $rsc),
 					)
