@@ -19,7 +19,7 @@ field private => sub {
 
 param remove;
 
-my @randomchars = qw(b c d f g h j k l m n p q r s t v w x z B C D F G H J K L M N P Q R S T V W X Z);
+my @randomchars = qw(b c d f g h j k l m n p q r s t v w x z);
 
 param submit;
 
@@ -41,9 +41,9 @@ field new_name => sub {
 
 field random_name => sub {
 	my $self = shift;
-	for(my $i = 0; $i < 10; $i++) {
+	for(my $i = 3; $i < 10; $i++) {
 		my $name = join('', map { $randomchars[$_ % @randomchars] }
-			unpack('S*', Crypt::OpenSSL::Random::random_bytes(2 * 5)));
+			unpack('S*', Crypt::OpenSSL::Random::random_bytes(2 * $i)));
 		return $name unless $self->name_info($name);
 	}
 };
@@ -72,7 +72,7 @@ field name_destination => sub { shift->name_owner; return };
 sub name_info {
 	my $name = shift;
 	my $db = $self->db;
-	my $q = $db->prepare_cached('SELECT url, owner, destination FROM urls WHERE name = ?');
+	my $q = $db->prepare_cached('SELECT url, owner, destination FROM urls WHERE lower(name) = lower(?)');
 	$q->execute($name);
 	my $res = $q->fetchrow_arrayref;
 	$q->finish;
@@ -129,7 +129,7 @@ field urls => sub {
 
 field anr => sub {
 	my $self = shift;
-	my $uid = $self->aselect_force_login;
+	my $uid = $self->login;
 	return $self->cfg->dir->anr($uid);
 };
 
@@ -164,7 +164,7 @@ field success => sub {
 
 	if(defined $self->remove) {
 		my $remove = $self->remove;
-		my ($num, $owner) = $self->name_info($remove);
+		my ($num, $owner, $url) = $self->name_info($remove);
 		if($owner) {
 			if($owner != $anr) {
 				push @$feedback, ['delete-notyours', $self->cfg->dir->displayname($owner)];
@@ -177,6 +177,7 @@ field success => sub {
 
 		return undef unless $self->nonce;
 
+		warn "$anr removed $remove ($url)\n";
 		$self->delentry($num);
 	} else {
 		if($self->cur_edit) {
@@ -232,6 +233,14 @@ field success => sub {
 
 		return undef unless $self->submit && $self->nonce;
 
+		my $name = $self->new_name;
+		my $url = $self->new_url;
+		if($self->new_edit) {
+			warn "$anr updated $name ($url)\n";
+		} else {
+			warn "$anr created $name ($url)\n";
+		}
+
 		$self->upsert;
 	}
 
