@@ -19,7 +19,7 @@ field url => sub {
 	return undef unless defined $name;
 
 	my $db = $self->db;
-	my $q = $db->prepare_cached('UPDATE urls SET atime = CURRENT_TIMESTAMP, visits = visits + 1 WHERE name = ? RETURNING destination, private');
+	my $q = $db->prepare_cached('UPDATE urls SET atime = CURRENT_TIMESTAMP, visits = visits + 1 WHERE lower(name) = lower(?) RETURNING destination, private');
 	$q->execute($name);
 	my $res = $q->fetchrow_arrayref;
 	$q->finish;
@@ -28,7 +28,7 @@ field url => sub {
 
 	my ($url, $private) = @$res;
 
-	$self->aselect_force_login if $private;
+	$self->login if $private;
 
 	return $url;
 };
